<?php

/**

 * Plugin Name: Docage Form

 * Description: Replaces a shortcode containing a Docage web form ID with an iframe containing the Docage web form with this ID.

 * Version: 2.1

 * Author: Docage

 */



function guid_iframe_shortcode_handler($atts) {

    $default_base_url = 'https://app.docage.com/Forms/Form?formId=';

    $atts = shortcode_atts(

        array(

            'id' => '',

            'base_url' => $default_base_url,

            'width' => '100%',

            'height' => '600',

        ),

        $atts,

        'docageform'

    );



    if (empty($atts['id'])) {

        return '';
    }

    $iframe_url = $atts['base_url'] . $atts['id'];



    return sprintf(

        '<iframe src="%s" width="%s" height="%s" frameborder="0" allowfullscreen></iframe>',

        esc_url($iframe_url),

        esc_attr($atts['width']),

        esc_attr($atts['height'])

    );

}

add_shortcode('docageform', 'guid_iframe_shortcode_handler');

function enqueue_plugin_scripts($hook) {
    // Only add to the post.php admin page.
    if($hook != 'post.php' && $hook != 'post-new.php'){
        return;
    }

    wp_enqueue_script('docageformbutton_script', plugin_dir_url(__FILE__) . 'js/docageformbutton.js', array('jquery'));
    wp_enqueue_style('docageformbutton_style', plugin_dir_url(__FILE__) . 'css/docageformbutton.css');
}
add_action('admin_enqueue_scripts', 'enqueue_plugin_scripts');

function register_docageformbutton($buttons) {
    array_push($buttons, "separator", "docageformbutton");
    return $buttons;
}

function add_docageformbutton_plugin($plugin_array) {
    $plugin_array['docageformbutton'] = plugin_dir_url(__FILE__) . 'js/docageformbutton.js';
    return $plugin_array;
}

function docageformbutton_hooks() {
    if (current_user_can('edit_posts') && current_user_can('edit_pages')) {
        add_filter("mce_external_plugins", "add_docageformbutton_plugin");
        add_filter("mce_buttons", "register_docageformbutton");
    }
}
add_action('init', 'docageformbutton_hooks');